harvester/harvesterserver/inc/cblacklistdb.h
changeset 9 d575fd691cf9
parent 7 a5fbfefd615f
--- a/harvester/harvesterserver/inc/cblacklistdb.h	Fri Jun 11 14:43:47 2010 +0300
+++ b/harvester/harvesterserver/inc/cblacklistdb.h	Wed Jun 23 19:26:19 2010 +0300
@@ -98,27 +98,27 @@
 	TBool FindL(TInt32 aPluginUid);
 	
 	/*
-     * @description Adds the given uid of a plugin to the unloadlist table.
+     * @description Adds the given uid of a plugin to the dontloadlist table.
      * @param aPluginUid Uid of the plugin
-     * @return sysmbian error code
+     * @return symbian error code
      * Leaves in case of errors.
      */  
-	TInt AddtoUnloadListL( TInt32 aPluginUid );
+	TInt AddtoDontloadListL( TInt32 aPluginUid );
     
 	/*
-     * @description remove the given uid of a plugin to the unloadlist table.
+     * @description remove the given uid of a plugin to the dontloadlist table.
      * @param aPluginUid Uid of the plugin
      * Leaves in case of errors.
      */  
-    void RemoveFromUnloadListL( TInt32 aPluginUid );
+    void RemoveFromDontloadListL( TInt32 aPluginUid );
     
     /*
-     * @description Find the given uid of a plugin to the unloadlist table.
+     * @description Find the given uid of a plugin to the dontloadlist table.
      * @param aPluginUid Uid of the plugin
      * @return ETrue if exists else returns EFalse
      * Leaves in case of errors.
      */  
-    TBool FindFromUnloadListL( TInt32 aPluginUid );
+    TBool FindInDontloadListL( TInt32 aPluginUid );
         
 private :
     /*
@@ -132,14 +132,14 @@
 	* @return CDbColSet database column set
     * Leaves in case of errors.
     */
-    CDbColSet* CreateColumnSetLC();
+    CDbColSet* CreateBlacklistColumnSetLC();
     
     /*
     * @description Creates Column set for unload table.
     * @return CDbColSet database column set
     * Leaves in case of errors.
     */
-    CDbColSet* CreateUnloadColumnSetLC();
+    CDbColSet* CreateDontloadColumnSetLC();
 private:    
     /*
      * A handle to a file server session.Owned
@@ -132,14 +132,14 @@
     
     /*
-    * @description Creates Column set for unload table.
+    * @description Creates Column set for dontload table.
     * @return CDbColSet database column set
     * Leaves in case of errors.